@@ -1,5 +1,7 @@
 # main 77
 # sam robson
+
+
 import warnings
 import cython
 import pyximport; pyximport.install()
@@ -32,10 +34,10 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group()
-@click.version_option("77.3.5", package_name="alacorder")
+@click.version_option("77.5", package_name="alacorder")
 def cli():
     """
-    ALACORDER beta 77.3
+    ALACORDER beta 77.5
 
     Alacorder retrieves case detail PDFs from Alacourt.com and processes them into text archives and data tables suitable for research purposes.
 
@@ -88,7 +90,7 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
     if debug:
         click.echo(outputs)
     if log:
-        click.echo(outputs.ECHO)
+        click.secho(outputs.ECHO, fg='yellow', italic=True)
     if not outputs.GOOD:
         raise Exception("Invalid output path!")
     if outputs.OUTPUT_EXT != ".xlsx" and outputs.OUTPUT_EXT != ".xls" and outputs.OUTPUT_EXT != ".dta" and outputs.OUTPUT_EXT != ".json" and outputs.OUTPUT_EXT != ".csv" and outputs.OUTPUT_EXT != ".zip" and outputs.OUTPUT_EXT != ".pkl":
@@ -182,7 +184,8 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
     if debug:
         click.echo(outputs)
     if log:
-        click.echo(outputs.ECHO)
+        click.secho(outputs.ECHO, fg='yellow', italic=True)
+
     if not outputs.GOOD:
         raise Exception("Invalid output path!")
 
@@ -204,8 +207,6 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
 
     if debug:
         click.echo(cf)
-    if log:
-        click.echo(cf.ECHO)
 
     o = cal.archive(cf)
 
@@ -304,7 +305,8 @@ def fetch(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update,
 
 
 def login(driver, cID, username, pwd, speed, no_log=False, path=""):
-    """Login to Alacourt.com using (driver) and auth (cID, username, pwd) at (speed) for browser download to directory at (path)
+    """
+    Login to Alacourt.com using (driver) and auth (cID, username, pwd) at (speed) for browser download to directory at (path)
     
     Args:
         driver (WebDriver): Google Chrome selenium.WebDriver() object
